/**
 * Create HTML element, setting classes, other attribures, text, and children.
 * @param  {string} type
 * DOM element type
 * @param  {string[]} classes=[]
 * Classes to apply to element
 * @param  {Object.<string, string>} attributes={}
 * Map of attribute name to value
 * @param  {string} iText=""
 * innerText of element (HTML escaped by browser)
 * @param  {HTMLElement[]} children=[]
 * Array of children
 * @returns {HTMLElement}
 * 
 * 
 * The created element
 */
function createElem(type, classes = [], attributes = {}, iText = "", children = []) {
    //Create elem
    var elem = document.createElement(type);
    //Add classes
    elem.classList.add(...classes);
    //Apply attributes
    for (var attname in attributes) {
        if(attributes[attname] !== undefined) elem.setAttribute(attname, attributes[attname]);
    }
    //Inner text
    elem.innerText = iText;
    //Childten
    for (var child in children) {
        elem.appendChild(children[child]);
    }
    return elem;
}

const SIGMA_MIN_DEF =1e-10
const SIGMA_DEF=0.001
var ntypes=1;
var nGRtypes=1;
var npartials= ntypes*(ntypes+1)/2;
var text_size="width:250px"
var nlead_tot=0 //this is the total for the leading series, if no NB then =ndata_tot+nbonded_tot, otherwise =ndata_tot 
var npotser_tot=0 //this is the total for the leading pot series, if no NB =0, =nNB_tot+nbonded_tot otherwise 
var nbonded_tot=0
var nNB_tot=0
var ndata_tot=0 //the total number of data sets and constraint 
var ngr_prev=0
var nsq_prev=0
var nfq_prev=0
var nfg_prev=0;
var nek_prev=0
var ncos_prev=0
var nic_prev=0
var icsub_prev=0
var nac_prev=0
var nconc_prev=0
var nsnc_prev=0
var is_bonded_prev=0;
var nbond_prev=0;
var nangle_prev=0;
var nperdih_prev=0;
var nharmdih_prev=0;
var nRBdih_prev=0;
var sigma_index=0
var sigma_pot_index=0
var lead_pot_ind=0
var leadpot_text=""
var master
var sigma_name
var sigma_min
var is_last_cos_file=0
//for the coeff sum=1 check
var last_type="NONE", prev_type="NONE", type_index=0
var sum_coeff=0.0

//1: no input box
//-1: no name field, only input box
function smallBlock(whereto, fields,noinpflag) 
{
    switch (noinpflag)
    {
    case 1://no input box
        this.makeHTML = function() {
            document.getElementById(whereto).appendChild(createElem("div", [], {}, "", [
                createElem("table", [], {}, "",
                fields.map(field => {
                    let inp = undefined;
                    let elem = createElem("tr", [], {}, "", [
                        inp = createElem("td", [], {id: field.id, value: field.name}, field.name, []),
                       
                    ]);
                    this.inputs.push([field, inp]);
                    return elem;
                })
            )]));
        }
        break;
    case -1:
        this.makeHTML = function() {
            document.getElementById(whereto).appendChild(createElem("div", [], {}, "", [
                createElem("table", [], {}, "",
                fields.map(field => {
                    let inp = undefined;
                    let elem = createElem("tr", [], {}, "", [
                       // createElem("td", [], {}, "", [
                         //   inp = createElem("input", [], {id: field.id, value: field.default, type:field.type, min:field.min, max:field.max, style:field.width_inp, align: field.align, oninput: field.oninput, ...(field.hidden != undefined ? {disabled:""} : {})})
                        //]),
                        //createElem("td", [], {}, field.description, []),
                        inp = createElem("input", [], {id: field.id, value: field.default, type:field.type, min:field.min, max:field.max, style:field.width_inp, align: field.align, oninput: field.oninput, ...(field.hidden != undefined ? {disabled:""} : {})})
                    ]);
                    this.inputs.push([field, inp]);
                    return elem;
                })
            )]));
        }
        break;
    default:
        this.makeHTML = function() {
            document.getElementById(whereto).appendChild(createElem("div", [], {}, "", [
                createElem("table", [], {}, "",
                fields.map(field => {
                    let inp = undefined;
                    let elem = createElem("tr", [], {}, "", [
                        createElem("td", [], {style:field.width}, field.name, []),
                        createElem("td", [], {}, "", [
                            inp = createElem("input", [], {id: field.id, value: field.default, type:field.type, min:field.min, max:field.max, style:field.width_inp, align: field.align, oninput: field.oninput, ...(field.hidden != undefined ? {disabled:""} : {})})
                        ]),
                        createElem("td", [], {}, field.description, []),
                    ]);
                    this.inputs.push([field, inp]);
                    return elem;
                })
            )]));
        }
    }
    this.getData = function() {
        return "";
    }

    this.inputs = [];
    this.makeHTML();
}






function block(name, fields) {
    this.getResult = function() {}
    this.makeHTML = function() {
        document.getElementById("main").appendChild(createElem("div", [], {}, "", [
            createElem("span", [], {}, "\n[" + name + "]"),
            createElem("table", [], {}, "",
            fields.map(field => {
                let inp = undefined;
                let elem = createElem("tr", [], {}, "", [
                    createElem("td", [], {style:text_size}, field.name, []),
                    createElem("td", [], {}, "", [
                        inp = createElem("input", [], {value: field.default, id: field.id, type:field.type, step: field.step, min:field.min, max:field.max, maxlength:field.maxlength, style:field.width, ...(field.hidden != undefined ? {disabled:""} : {})})
                    ]),
                    createElem("td", [], {}, field.description, []),
                ]);
                this.inputs.push([field, inp]);
                return elem;
            })
        )]));
    }
    this.getData = function() {
        let mytext="\n[" + name + "]\n";
        let temptext="";
        temptext=this.inputs.reduce((prev, input) => 
        {
             if (prev=="abort")
                return "abort";
           
            if (input[1].value=="GR" || input[1].value=="ND")
            {
                last_type=input[1].value;
                if (last_type!=prev_type)//this is the first from this data set type
                {
                    type_index=0;
                    prev_type=last_type;
                    index=1;
                }
            }
            let text=" " + input[0].name + " = " + input[1].value + "\t\t! --" + input[0].description + "\n";
            //If mandatory value is missing, do noot save file
            //if optional value is missing do not save that line
            if (input[0].name=="DISTRIB-TYPE")
            {
                if (input[1].value=="UNIFORM" || input[1].value=="GAUSSIAN" || input[1].value=="ABSENT")
                    is_last_cos_file=0;
                else
                    is_last_cos_file=1;
                
      
            }
            if (input[1].value=="")
            {
                if (input[0].status=="M" )
                {
                    window.alert("No value was given for "+input[0].name+"!");
                    prev="";
                    text="abort";
                }
                else
                {
                    if (input[0].status=="OM" && is_last_cos_file==0)
                    {
                        window.alert("No value was given for "+input[0].name+"!");
                        prev="";
                        text="abort";
                    }
                    else
                        text="";
                }
            }
           
            return prev + text;
        }, "") + "";
       
        if (temptext!="abort")
            return mytext+temptext;
        else
            return "abort"
    }
    

    this.inputs = [];
    this.makeHTML();
}

//here name is a switch
//name: "", 2, 3, 4, 5 (all strings) create 1, 2, 3, 4, 5 consecutive input box 
//0, -2 not to go to next line after
//-2 write '1-1' extension to name, cannot be part field name, as this should not be saved, only for display
//-3 write '1' extension to name, same as before
//-1 create select box instead of input box
//whether the sigma is scalable can only be decided from the vaule, and if negative, ...SCALABLE will be written to file
function subblock(name, fields, newline) {
    var sep="\n";
    var ext="";
    if (newline==-2)
        ext="1-1";
    if (newline==-3)
        ext="1";
    if (newline==0 || newline==-2 || newline==-3)
        sep="";
 
    var FNC_options = [
        createElem('option', [], {value: 'NONE', default: 'NONE'}, 'NONE'),
        createElem('option', [], {value: 'NORMAL'}, 'NORMAL'),
        createElem('option', [], {value: 'ADJUST'}, 'ADJUST'),
        createElem('option', [], {value: 'MOVE-IN'}, 'MOVE-IN')
    ];

    this.getResult = function() {}

    switch (name)
    {
        case '-1':
            this.makeHTML = function() {
                document.getElementById("main").appendChild(createElem("div", [], {}, "", [
                    createElem("table", [], {}, "",
                    fields.map(field => {
                       
                        let elem = createElem("tr", [], {}, "", [
                            createElem("td", [], {style:text_size}, field.name+ext, []),
                            createElem("td", [], {}, "", [
                                inp = createElem("select", [], {value: field.default, type:field.type, step: field.step, min:field.min, max:field.max, style:field.width, ...(field.hidden != undefined ? {disabled:""} : {})},"",FNC_options)
                            ]),
                            createElem("td", [], {}, field.description, []),
                        ]);
                        this.inputs.push([field, inp]);
                        return elem;
                    })
                )]));
            }
            break;
        case '2':
            this.makeHTML = function() {
                document.getElementById("main").appendChild(createElem("div", [], {}, "", [
                    createElem("table", [], {}, "",
                    fields.map(field => {
                       
                        let elem = createElem("tr", [], {}, "", [
                            createElem("td", [], {style:text_size}, field.name+ext, []),
                            createElem("td", [], {}, "", [
                                inp = createElem("input", [], {value: field.default, type:field.type, step: field.step, min:field.min, max:field.max, style:field.width, ...(field.hidden != undefined ? {disabled:""} : {})})
                            ]),
                            createElem("td", [], {}, "", [
                                inp2 = createElem("input", [], {value: field.default2, type:field.type2, step: field.step2, min:field.min2, max:field.max2, style:field.width2, ...(field.hidden2 != undefined ? {disabled:""} : {})})
                            ]),
                            createElem("td", [], {}, field.description, []),
                        ]);
                        this.inputs.push([field, inp,inp2]);
                        return elem;
                    })
                )]));
            }
            break;

        case '3':
            this.makeHTML = function() {
                document.getElementById("main").appendChild(createElem("div", [], {}, "", [
                    createElem("table", [], {}, "",
                    fields.map(field => {
                       
                        let elem = createElem("tr", [], {}, "", [
                            createElem("td", [], {style:text_size}, field.name+ext, []),
                            createElem("td", [], {}, "", [
                                inp = createElem("input", [], {value: field.default, type:field.type, step: field.step, min:field.min, max:field.max, style:field.width, ...(field.hidden != undefined ? {disabled:""} : {})})
                            ]),
                            createElem("td", [], {}, "", [
                                inp2 = createElem("input", [], {value: field.default2, type:field.type2, step: field.step2, min:field.min2, max:field.max2, style:field.width2, ...(field.hidden2 != undefined ? {disabled:""} : {})})
                            ]),
                            createElem("td", [], {}, "", [
                                inp3 = createElem("input", [], {value: field.default3, type:field.type3, step: field.step2, min:field.min3, max:field.max3, style:field.width3, ...(field.hidden3 != undefined ? {disabled:""} : {})})
                            ]),
                            createElem("td", [], {}, field.description, []),
                        ]);
                        this.inputs.push([field, inp,inp2,inp3]);
                        return elem;
                    })
                )]));
            }
            break;
        case '4':
            this.makeHTML = function() {
                document.getElementById("main").appendChild(createElem("div", [], {}, "", [
                    createElem("table", [], {}, "",
                    fields.map(field => {
                       
                        let elem = createElem("tr", [], {}, "", [
                            createElem("td", [], {style:text_size}, field.name+ext, []),
                            createElem("td", [], {}, "", [
                                inp = createElem("input", [], {value: field.default, type:field.type, step: field.step, min:field.min, max:field.max, style:field.width, ...(field.hidden != undefined ? {disabled:""} : {})})
                            ]),
                            createElem("td", [], {}, "", [
                                inp2 = createElem("input", [], {value: field.default2, type:field.type2, step: field.step2, min:field.min2, max:field.max2, style:field.width2, ...(field.hidden2 != undefined ? {disabled:""} : {})})
                            ]),
                            createElem("td", [], {}, "", [
                                inp3 = createElem("input", [], {value: field.default3, type:field.type3, step: field.step3, min:field.min3, max:field.max3, style:field.width3, ...(field.hidden3 != undefined ? {disabled:""} : {})})
                            ]),
                            createElem("td", [], {}, "", [
                                inp4 = createElem("input", [], {value: field.default4, type:field.type4, step: field.step4, min:field.min4, max:field.max4, style:field.width4, ...(field.hidden4 != undefined ? {disabled:""} : {})})
                            ]),
                            createElem("td", [], {}, field.description, []),
                        ]);
                        this.inputs.push([field, inp,inp2,inp3,inp4]);
                        return elem;
                    })
                )]));
            }
            break;
            case '5':
                this.makeHTML = function() {
                    document.getElementById("main").appendChild(createElem("div", [], {}, "", [
                        createElem("table", [], {}, "",
                        fields.map(field => {
                           
                            let elem = createElem("tr", [], {}, "", [
                                createElem("td", [], {style:text_size}, field.name+ext, []),
                                createElem("td", [], {}, "", [
                                    inp = createElem("input", [], {value: field.default, type:field.type, step: field.step, min:field.min, max:field.max, style:field.width, ...(field.hidden != undefined ? {disabled:""} : {})})
                                ]),
                                createElem("td", [], {}, "", [
                                    inp2 = createElem("input", [], {value: field.default2, type:field.type2, step: field.step2, min:field.min2, max:field.max2, style:field.width2, ...(field.hidden2 != undefined ? {disabled:""} : {})})
                                ]),
                                createElem("td", [], {}, "", [
                                    inp3 = createElem("input", [], {value: field.default3, type:field.type3, step: field.step3, min:field.min3, max:field.max3, style:field.width3, ...(field.hidden3 != undefined ? {disabled:""} : {})})
                                ]),
                                createElem("td", [], {}, "", [
                                    inp4 = createElem("input", [], {value: field.default4, type:field.type4, step: field.step4, min:field.min4, max:field.max4, style:field.width4, ...(field.hidden4 != undefined ? {disabled:""} : {})})
                                ]),
                                createElem("td", [], {}, "", [
                                    inp5 = createElem("input", [], {value: field.default5, type:field.type5, step: field.step5, min:field.min5, max:field.max5, style:field.width5, ...(field.hidden5 != undefined ? {disabled:""} : {})})
                                ]),    
                                createElem("td", [], {}, field.description, []),
                            ]);
                            this.inputs.push([field, inp,inp2,inp3,inp4,inp5]);
                            return elem;
                        })
                    )]));
                }
                break;
        default:
            this.makeHTML = function() {
                document.getElementById("main").appendChild(createElem("div", [], {}, "", [
                    createElem("table", [], {}, "",
                    fields.map(field => {
                       
                        let elem = createElem("tr", [], {}, "", [
                            createElem("td", [], {style:text_size}, field.name+ext, []),
                            createElem("td", [], {}, "", [
                                inp = createElem("input", [], {value: field.default, type:field.type, step: field.step, min:field.min, max:field.max, style:field.width, ...(field.hidden != undefined ? {disabled:""} : {})})
                            ]),
                            createElem("td", [], {}, field.description, []),
                        ]);
                        this.inputs.push([field, inp]);
                        return elem;
                    })
                )]));
            }
    }
    
    
    
    this.getData = function() {
        let mytext="";
        let temptext="";
        temptext=this.inputs.reduce((prev, input) => 
        {
             if (prev=="abort")
                return "abort";
         
            let desc="\t\t! --" +input[0].description;
            let values= input[1].value;

            if (input[0].name.indexOf("PARTIAL-COEFFS")!=-1)
            {
                if (input[0].name=="PARTIAL-COEFFS")//first
                {
                    type_index++;
                    sum_coeff= parseFloat(input[1].value);
                }
                else
                {  
                    sum_coeff+= parseFloat(input[1].value);
                    if (input[0].name=="PARTIAL-COEFFS"+ntypes.toString()+"-"+ntypes.toString())//last element
                    {
                        if (Math.abs(sum_coeff-1)>1e-6)//not normalized to have sum 1
                        {
                            let myn=parseFloat(sum_coeff);
                            alert("The sum of the coefficients for the "+type_index+". "+last_type+" is "+myn.toFixed(8)+", and not 1!\nCorrect it, cannot save it now!");
                            prev="";
                            text="abort";
                        }
                    }
                }
            }
            if (input[0].name=="SIGMA" && parseFloat(input[1].value)<0)//scalable sigma
            {
                input[0].name="SIGMA-SCALABLE";
                values=Math.abs(parseFloat(input[1].value));
            }
            //for the values of the vdW and Coulomb sigma, the name can contain the index of the partial
            if (input[0].name.indexOf("VDW-SIGMA")!=-1)
            {
                sigma_pot_index++;
                if (parseFloat(input[1].value)<0)//scalable sigma)
                {
                    if (sigma_pot_index==lead_pot_ind)
                        values="ms"+Math.abs(parseFloat(input[1].value)).toString();
                    else
                        values="s"+Math.abs(parseFloat(input[1].value)).toString();
                }
                else
                {
                    if (sigma_pot_index==lead_pot_ind)
                        values="m"+Math.abs(parseFloat(input[1].value)).toString();
                }
            }
            if (input[0].name.indexOf("COUL-SIGMA")!=-1)
            {
                sigma_pot_index++;
                if (parseFloat(input[1].value)<0)//scalable sigma)
                {
                    if (sigma_pot_index==lead_pot_ind)
                        values="ms"+Math.abs(parseFloat(input[1].value)).toString();
                    else
                        values="s"+Math.abs(parseFloat(input[1].value)).toString();
                }
                else
                {
                    if (sigma_pot_index==lead_pot_ind)
                        values="m"+Math.abs(parseFloat(input[1].value)).toString();
                }
            }
            let key= input[0].name + " = " ;             
            if (newline==-1)
                key="";
            if (newline==0 || newline==-2 || newline==-3)
                desc="";
            if (name=='2')
            {
                if (input[0].name=="COORDNUM_SIGMA" && parseFloat(input[2].value)<0)//scalable sigma
                {
                    input[0].name="COORDNUM_SIGMA-SCALABLE";
                    key= input[0].name + " = " ;    
                    values+=" "+Math.abs(parseFloat(input[2].value));
                }
                else
                    values+=" "+input[2].value;
            }
            if (name=='3')
            {
                if (input[0].name=="COORDNUM_FRACT_SIGMA" && parseFloat(input[3].value)<0)//scalable sigma
                {
                    input[0].name="COORDNUM_FRACT_SIGMA-SCALABLE";
                    key= input[0].name + " = " ;    
                    values+=" "+input[2].value+" "+Math.abs(parseFloat(input[3].value));
                }
                else
                {
                    if (input[0].name=="IND_SIGMA_FILE" && parseFloat(input[2].value)<0)//scalable sigma
                    {
                        let mynum=parseFloat(input[2].value);
                        input[0].name="IND_SIGMA-SCALABLE_FILE";
                        key= input[0].name + " = " ;    
                        values+=" "+Math.abs(parseFloat(input[2].value))+" "+input[3].value;
                    }
                    else
                        values+=" "+input[2].value+" "+input[3].value;
                }
                
            }
       
            if (name=='4')
                values+=" "+input[2].value+" "+input[3].value+" "+input[4].value;
            if (name=='5')
                values+=" "+input[2].value+" "+input[3].value+" "+input[4].value+" "+input[5].value;
            let text=" " + key + values +  desc + sep;
            //If mandatory value is missing, do noot save file
            //if optional value is missing do not save that line
            switch (name)
            {
            case '5':
                if (input[5].value=="")
                {
                    if (input[0].status5=="M" )
                    {
                        window.alert("No value was given for "+input[0].name+" field 5!");
                        prev="";
                        text="abort";
                    }
                    else
                        text="";
                }
            case '4':
                if (input[4].value=="")
                {
                    if (input[0].status4=="M" )
                    {
                        window.alert("No value was given for "+input[0].name+" field 4!");
                        prev="";
                        text="abort";
                    }
                    else
                        text="";
                }
            case '3':
                if (input[3].value=="")
                {
                    if (input[0].status3=="M" )
                    {
                        window.alert("No value was given for "+input[0].name+" field 3!");
                        prev="";
                        text="abort";
                    }
                    else
                        text="";
                }
            case '2':
                if (input[2].value=="")
                {
                    if (input[0].status2=="M" )
                    {
                        window.alert("No value was given for "+input[0].name+" field 2!");
                        prev="";
                        text="abort";
                    }
                    else
                        text="";
                }
            default:

                if (input[1].value=="")
                {
                    if (input[0].status=="M" )
                    {
                        window.alert("No value was given for "+input[0].name+"!");
                        prev="";
                        text="abort";
                    }
                    else
                        text="";
                }
            }
                    
            return prev + text;
        }, "");
    if (temptext!="abort")
        return mytext+temptext;
    else
        return "abort"
    }
  
    this.inputs = [];
    this.makeHTML();
}
function subblock_mid(name, fields, newline) {
    let sep="\n";
    if (newline==0)
    {
        sep="";
    }
    
    this.getResult = function() {}
    this.makeHTML = function() {
        document.getElementById("main").appendChild(createElem("div", [], {}, "", [
            createElem("table", [], {}, "",
            fields.map(field => {
               
                let elem = createElem("tr", [], {}, "", [
                    createElem("td", [], {style:text_size}, field.name, []),
                    createElem("td", [], {}, "", [
                        inp = createElem("input", [], {value: field.default, type:field.type, step: field.step, min:field.min, max:field.max, ...(field.hidden != undefined ? {disabled:""} : {})})
                    ]),
                   
                ]);
                this.inputs.push([field, inp]);
                return elem;
            })
        )]));
    }
    this.getData = function() {
        return  this.inputs.reduce((prev, input) => {
            let values=input[1].value;
      
            if (input[0].name.indexOf("PARTIAL-COEFFS")!=-1)
                sum_coeff+= parseFloat(input[1].value);
            if (input[0].name.indexOf("VDW-SIGMA")!=-1)
            {
                sigma_pot_index++;
                if (parseFloat(input[1].value)<0)//scalable sigma)
                {
                    if (sigma_pot_index==lead_pot_ind)
                        values="ms"+Math.abs(parseFloat(input[1].value)).toString();
                    else
                        values="s"+Math.abs(parseFloat(input[1].value)).toString();
                }
                else
                {
                    if (sigma_pot_index==lead_pot_ind)
                        values="m"+Math.abs(parseFloat(input[1].value)).toString();
                }
            }
            if (input[0].name.indexOf("COUL-SIGMA")!=-1)
            {
                sigma_pot_index++;        
                if (parseFloat(input[1].value)<0)//scalable sigma)
                {
                    if (sigma_pot_index==lead_pot_ind)
                        values="ms"+Math.abs(parseFloat(input[1].value)).toString();
                    else
                        values="s"+Math.abs(parseFloat(input[1].value)).toString();
                }
                else
                {
                    if (sigma_pot_index==lead_pot_ind)
                        values="m"+Math.abs(parseFloat(input[1].value)).toString();
                }
            }
            if (input[1].value=="")//here the remainder of this data line can be inother physical line and block, abort anyway
            {
                window.alert("No value was given for "+input[0].name+"!");
                return "abort";
            }
            return prev + " " + values+sep ;
        }, "");
    }

    this.inputs = [];
    this.makeHTML();
}


let blocks = [];
function start() {
    ntypes=parseInt(document.getElementById("ntypes").value);
    var flag=0;
    
    CheckLeadIndTot();
    CheckLeadPotIndTot();
    blocks.push(new block(" GENERAL ", [
        {name: "TITLE",default:"", type: "text", maxlength:80, width: "width:500px", description: "Title of the run (default: blank)"}
    ]));
    blocks.push(new subblock("", [
        {name: "NDENS", default:"" ,type:"number",step:"any", min:0, description: "Number density in 1/A^3 (default: Calculated from *.cfg)"},
    ]));

    for(let i = 0; i < ntypes; i++) 
    {
        for (let j = i; j < ntypes; j++)
        {
            if (ntypes==1)
            {
                blocks.push(new subblock("", [
                    {name: "CUT-OFF", default:"", type: "number", step: "any", min: 0, status: "M", description: "Closest distance approach)"},
                ]));
            }
            else
            {
                if (i==0 && j==0)
                {
                    blocks.push(new subblock("", [
                        {name: "CUT-OFF", default:"", type: "number", step: "any", min: 0, status: "M",}
                    ],-2));
                }
                else
                {
                    if (i==ntypes-1 && j==ntypes-1)
                    {
                        
                        blocks.push(new subblock("", [
                            {name: "CUT-OFF"+(i+1)+"-"+(j+1), default:"", type: "number", step: "any", min: 0, status: "M", description: "Closest distance approach for each partials in A (in 11,12,...,22,23.. order)"},
                        ],-1));
                    }
                    else
                    {
                        if (j==ntypes-1)
                            flag=1;
                        else
                            flag=0;
                        blocks.push(new subblock_mid("", [
                            {name: "CUT-OFF"+(i+1)+"-"+(j+1), default:"", type: "number", step: "any", min: 0, status: "M",},
                        ],flag));
                    }
                }
            }
        }
    }
    for(let i = 0; i < ntypes; i++) 
    {
        if (ntypes==1)
        {
            blocks.push(new subblock("", [
                {name: "MAX-MOVES", default: 0.1, type:"number", step: "any", min:0, description: "Maximum move for each atom type in A (default: 0.1)"},
            ]));
        }
        else
        {
            if (i==0)
            {
                blocks.push(new subblock("", [
                    {name: "MAX-MOVES", default:"0.1", type: "number", step: "any", min: 0}
                ],-3));
            }
            else
            {
                if (i==ntypes-1)
                {
                    
                    blocks.push(new subblock("", [
                        {name: "MAX-MOVES"+(i+1), default:"0.1", type: "number", step: "any", min: 0, description: "Maximum move for each atom type in A (default: 0.1)"},
                    ],-1));
                }
                else
                {
                    blocks.push(new subblock_mid("", [
                        {name: "MAX-MOVES"+(i+1), default:"0.1", type: "number", step: "any", min: 0},
                    ],0));
                }
            }
        } 
    }
    for(let i = 0; i < ntypes; i++) 
    {
        if (ntypes==1)
        {
            blocks.push(new subblock("", [
                {name: "R-SPACING", default: 0.1, type:"number", step: "any", min:0, description: "Size of the histogram bins in A (default: 0.1)"},
            ]));
        }
        else
        {
            if (i==0)
            {
                blocks.push(new subblock("", [
                    {name: "R-SPACING", default:"0.1", type: "number", step: "any", min: 0}
                ],-3));
            }
            else
            {
                if (i==ntypes-1)
                {
                    
                    blocks.push(new subblock("", [
                        {name: "R-SPACING"+(i+1), default:"0.1", type: "number", step: "any", min: 0, description: "Size of the histogram bins in A (default: 0.1)"},
                    ],-1));
                }
                else
                {
                    blocks.push(new subblock_mid("", [
                        {name: "R-SPACING"+(i+1), default:"0.1", type: "number", step: "any", min: 0},
                    ],0));
                }
            }
        }   
    }
    blocks.push(new subblock("", [     
        {name: "BIN-SHIFT", default: 0, type:"number", step: "any",  min:0,description: "Number of bins to leave out from the calculation at the beginning of the histogram (default: 0)"},
        {name: "XMAX-FACTOR", default: 1.0, type:"number", step: "any",  min:0,description: "Largest distance between the particles to include in the histogram calculation in reduced unit, maximum sqrt(3) (default: 1.0)"},
    ]));
    blocks.push(new subblock("-1", [ 
        {name: "FNC-TYPE", default: "NONE", type:"text", width: "width:140px", description: "Type of the FNC constraint possible values: NONE, NORMAL, ADJUST, MOVE-IN (default: NONE)"},     
    ]));
    blocks.push(new subblock("", [     
        {name: "RELOAD", default: 0, type:"number", min:0, max:1, description: "Whether to load the histogram from disc (default: 0)"},
        {name: "ATOMS-IN-GRIDCELL", default: 5, type:"number", min: 1, description: "Number of atoms in a grid cell (default: 5)"},
        {name: "EXAFS-SHIFTSTEP", default: 1000, type:"number",  min:0, description: "Shift E0 and so forth k for selected EXAFS data set in each EXAFS-SHIFTSTEP step (default: 1000)"},
        {name: "MAX-NITER-NONLIN", default: 1000, type:"number",  min:0, description: "Maximum number of iteration in case of I(Q) fitting with non-linear regression (default: 1000)"},
        {name: "EPSILON-NONLIN", default: 0.001, type:"number", step: "any", min:0, description: "Iteration stops, if the fitted parameters change less than this (default: 0.001)"},
        {name: "LAMBDA-NONLIN", default: 0.001, type:"number", step: "any",  min:0, description: "Fudge factor for Levenberg-Marquardt non-linear regression (default: 0.001)"},
        {name: "FACTOR-NONLIN", default: 10.0, type:"number", step: "any", min:0, description: "Factor to change fudge for Levenberg-Marquardt non-linear regression (default: 10.0)"},
        {name: "TERMINATE-NONLIN", default: 10, type:"number",  min:1, description: "Terminate after this many successive moves ended with failed non-linear regression (default: 10)"},
        {name: "THREADS", default: 1, type:"number",  min:1, description: "Number of threads to use (default: 1)"},
        {name: "RUN-TIME", default: 300, type:"number",  min:0, description: "Run time in minutes (default: 300)"},
        {name: "SAVE-TIME", default: 2, type:"number",  min:1, description: "Saving to the disk in minutes (default: 2)"},
        {name: "HST_BUFFSIZE", default: 0, type:"number",  min:0, description: "Size of the history buffer, 0 no history (default: 0)"},
        {name: "HST-STEP-FACTOR", default: 1, type:"number",  min:0, description: "Number of savings to disc between history buffering (default: 1)"},
        {name: "COLL-NUMBER", default: 0, type:"number",  min:0, description: "Number of configurations to collect at the end of the run (default: 0)"},
        {name: "COLL-STEP-FACTOR", default: 1, type:"number",  min:1, description: "A configuration will be saved at each COLL-STEP-FACTOR*SAVE-TIME (default: 1)"},
        {name: "PRINT-STEP", default: 10000, type:"number",  min:1, description: "Number of generated moves between printing to general output (default: 10000)"},
        {name: "MOVEOUT", default: 1, type:"number", min:0, max:1, description: "Whether to use moveout option 0/1 (default: 1)"},
        {name: "CREATE-OUT", default: 0, type:"number",  min:0, max:1, description: "Whether to write old format *.out file 0/1 (default: 0)"},
        {name: "PPCF-AVERAGE", default: 0, type:"number", min:0, max:1, description: "Whether to write summed ppcfs to the *.ppcf file as well at each saving 0/1 (default: 0)"},
        {name: "WRITE-LOG", default: 0, type:"number", min:0, max:1, description: "Whether to create a log file 0/1 (default: 0)"},
        {name: "LOG-NONLIN-STEPS", default: 0, type:"number",min:0, max:1, description: "Write non-linear regression steps, if there is any 0/1 (default: 0)"},
        {name: "WRITE-EXAFS-COEFFS", default: 0, type:"number", min:0, max:1, description: "Whether to write the EXAFS coefficients to the *.expt file, only active if E0 shift is applied 0/1 (default: 0)"},
        {name: "DEBUG", default: 0, type:"number", min:0, max:1, description: "Write debug information 0/1 (default: 0)"},
        {name: "LAST-GEN", default: 1000, type:"number", min:1, description: "Number of generated moves to run in _TEST_MODE (default: 1000)"},
        {name: "R-SWITCH-POWER", default: 2, type:"number", min:1, description: "Modify the default value for the _R_SWITCH_GR_MIN_1 compiler option, if it is on, then\n\t\t\t\t! experimental g(r) data sets will be interpreted as (r^r_switch_power)*[g(r)-1], and this will be calculated and fitted (default: 2)"},
    ]));


    for(let i = 0; i < document.getElementById("ngr").value; i++) {
        sigma_index++;
        master=0;
        if (sigma_index==document.getElementById("lead_series_ind").value)
            master=1;
        blocks.push(new block(" EXP ", [
            {name: "TYPE", default:"GR", type: "text", description: "Type of the experimental set", hidden:true},
            {name: "DATAFILE", default:"", type: "text", status: "M", description: "Name of the data file"},
            {name: "CONST-SUBTRACT", default: 0, type:"number", step: "any", description: "Constant to subtract from the data points (default: 0)"},
            {name: "R-SPACING", default: 0.1, type:"number", step: "any", min:0, description: "Size of the histogram bins in A (default: 0.1)"},
            {name: "USE-RFACTOR", default: 0, type:"number", min:0, max:1, description: "Whether to use R-factor instead of normal chi2 for this set 0/1 (default: 0)"},
        ]));

        if (master==1)
        {
            sigma_name="SIGMA-MASTER";
            sigma_min=SIGMA_MIN_DEF;
        }
        else
        {
            sigma_name="SIGMA"
            sigma_min="any";
        }
        blocks.push(new subblock("", [
            {name: sigma_name, name_s: "SIGMA-SCALABLE", default: SIGMA_DEF, type:"number", step: "any", status: "M", min: sigma_min, description: "Sigma parameter (default: 0.001)"},
        ]));
      
        for(let i = 0; i < ntypes; i++) 
        {
            for (let j = i; j < ntypes; j++)
            {
                if (ntypes==1)
                {
                    blocks.push(new subblock("", [
                        {name: "PARTIAL-COEFFS", default: 1.0, type:"number", step: "any", description: "Npartial number coefficients for the partials",hidden:true},
                    ]));
                }
                else
                {
                    if (i==0 && j==0)
                    {
                        blocks.push(new subblock("", [
                            {name: "PARTIAL-COEFFS", default:"", type: "number", step: "any", min: 0, max:1.0}
                        ],-2));
                    }
                    else
                    {
                        if (i==ntypes-1 && j==ntypes-1)
                        {
                            
                            blocks.push(new subblock("", [
                                {name: "PARTIAL-COEFFS"+(i+1)+"-"+(j+1), default:"", type: "number", step: "any", min: 0, max:1.0, description: "Npartial number coefficients for the partials"},
                            ],-1));
                        }
                        else
                        {
                            if (j==ntypes-1)
                                flag=1;
                            else
                                flag=0;
                            blocks.push(new subblock_mid("", [
                                {name: "PARTIAL-COEFFS"+(i+1)+"-"+(j+1), default:"", type: "number", step: "any", min: 0, max:1.0},
                            ],flag));
                        }
                    }
                }
            }
        }
        blocks.push(new subblock("2", [
            {name: "POINT-RANGE", default: 1, type:"number", min:1, type2:"number", min2:1, description: "First and last data points to use"},           
        ]));
        blocks.push(new subblock("", [
            {name: "RENORM", default: 0, type:"number",  min:0, max:1, description: "Whether to use renormalization coefficient, 0/1 (default: 0)"},
        ]));
        blocks.push(new subblock("4", [ 
            {name: "POLY-BACK-FLAGS", default: 0, type:"number", min:0, max:1, default2: 0, type2:"number", min2:0, max2:1, default3: 0, type3:"number", min3:0, max3:1, default4: 0, type4:"number", min4:0, max4:1, description: "Whether to use polinomial background correction, only offset available 0/1 (default: 0)"},
        ]));
    }


    for(let i = 0; i < document.getElementById("nsq").value; i++) {
        sigma_index++;
        master=0;
        if (sigma_index==document.getElementById("lead_series_ind").value)
            master=1;
        blocks.push(new block(" EXP ", [
            {name: "TYPE", default:"ND", type: "text", description: "Type of the experimental set", hidden:true},
            {name: "DATAFILE", default:"", type: "text", status: "M", description: "Name of the data file"},
            {name: "CONST-SUBTRACT", default: 0, type:"number", step: "any", description: "Constant to subtract from the data points (default: 0)"},
            {name: "R-SPACING", default: 0.1, type:"number", step: "any", min:0, description: "Size of the histogram bins in A (default: 0.1)"},
            {name: "USE-RFACTOR", default: 0, type:"number", min:0, max:1, description: "Whether to use R-factor instead of normal chi2 for this set 0/1 (default: 0)"}
        ]));
        if (master==1)
        {
            sigma_name="SIGMA-MASTER";
            sigma_min=SIGMA_MIN_DEF;
        }
        else
        {
            sigma_name="SIGMA"
            sigma_min="any";
        }
        blocks.push(new subblock("", [
            {name: sigma_name, name_s: "SIGMA-SCALABLE", default: SIGMA_DEF, type:"number", step: "any", status: "M", min: sigma_min, description: "Sigma parameter (default: 0.001)"},
        ]));
        for(let i = 0; i < ntypes; i++) 
        {
            for (let j = i; j < ntypes; j++)
            {
                if (ntypes==1)
                {
                    blocks.push(new subblock("", [
                        {name: "PARTIAL-COEFFS", default: 1.0, type:"number", step: "any", description: "Npartial number coefficients for the partials",hidden:true},
                    ]));
                }
                else
                {
                    if (i==0 && j==0)
                    {
                        blocks.push(new subblock("", [
                            {name: "PARTIAL-COEFFS", default:"", type: "number", step: "any", min: 0, max:1.0}
                        ],-2));
                    }
                    else
                    {
                        if (i==ntypes-1 && j==ntypes-1)
                        {
                            
                            blocks.push(new subblock("", [
                                {name: "PARTIAL-COEFFS"+(i+1)+"-"+(j+1), default:"", type: "number", step: "any", min: 0, max:1.0, description: "Npartial number coefficients for the partials"},
                            ],-1));
                        }
                        else
                        {
                            if (j==ntypes-1)
                                flag=1;
                            else
                                flag=0;
                            blocks.push(new subblock_mid("", [
                                {name: "PARTIAL-COEFFS"+(i+1)+"-"+(j+1), default:"", type: "number", step: "any", min: 0, max:1.0},
                            ],flag));
                        }
                    }
                }
            }
        }
        blocks.push(new subblock("2", [
            {name: "POINT-RANGE", default: 1, type:"number", min:1, type2:"number", min2:1, description: "First and last data points to use"},           
        ]));
        blocks.push(new subblock("", [
            {name: "RENORM", default: 0, type:"number",  min:0, max:1, description: "Whether to use renormalization coefficient, 0/1 (default: 0)"},
        ]));
        blocks.push(new subblock("4", [ 
            {name: "POLY-BACK-FLAGS", default: 0, type:"number", min:0, max:1, default2: 0, type2:"number", min2:0, max2:1, default3: 0, type3:"number", min3:0, max3:1, default4: 0, type4:"number", min4:0, max4:1, description: "Whether to use polinomial background correction, only offset available 0/1 (default: 0)"},
        ]));
    }


    for(let i = 0; i < document.getElementById("nfq").value; i++) {
        sigma_index++;
        master=0;
        if (sigma_index==document.getElementById("lead_series_ind").value)
            master=1;
        blocks.push(new block(" EXP ", [
            {name: "TYPE", default:"XRD", type: "text", description: "Type of the experimental set", hidden:true},
            {name: "DATAFILE", default:"", type: "text", status: "M", description: "Name of the data file"},
            {name: "CONST-SUBTRACT", default: 0, type:"number", step: "any", description: "Constant to subtract from the data points (default: 0)"},
            {name: "R-SPACING", default: 0.1, type:"number", step: "any", min:0, description: "Size of the histogram bins in A (default: 0.1)"},
            {name: "USE-RFACTOR", default: 0, type:"number", min:0, max:1, description: "Whether to use R-factor instead of normal chi2 for this set 0/1 (default: 0)"}
        ]));
        if (master==1)
        {
            sigma_name="SIGMA-MASTER";
            sigma_min=SIGMA_MIN_DEF;
        }
        else
        {
            sigma_name="SIGMA"
            sigma_min="any";
        }
        blocks.push(new subblock("", [
            {name: sigma_name, name_s: "SIGMA-SCALABLE", default: SIGMA_DEF, type:"number", step: "any", status: "M", min: sigma_min, description: "Sigma parameter (default: 0.001)"},
        ]));
        blocks.push(new subblock("2", [
            {name: "POINT-RANGE", default: 1, type:"number", min:1, type2:"number", min2:1, description: "First and last data points to use"},           
        ]));
        blocks.push(new subblock("", [
            {name: "RENORM", default: 0, type:"number",  min:0, max:1, description: "Whether to use renormalization coefficient, 0/1 (default: 0)"},
        ]));
        blocks.push(new subblock("4", [ 
            {name: "POLY-BACK-FLAGS", default: 0, type:"number", min:0, max:1, default2: 0, type2:"number", min2:0, max2:1, default3: 0, type3:"number", min3:0, max3:1, default4: 0, type4:"number", min4:0, max4:1, description: "Whether to use polinomial background correction, only offset available 0/1 (default: 0)"},
            {name: "I(Q)_A_B_ALPHA", default: 0, type:"number",  min:0, max:1, default2: 1.0, type2:"number", step: "any", default3: 0.0, type3:"number", step: "any", default4: 0.0, type4:"number", step: "any", description: "Indicator to fit I(Q) instead of F(Q) 0/1, if custom values are needed should be supplied here.\n\t! If b and alpha custom value is needed, something for a value should be given as well! (default: 0)"},
        ]));
        blocks.push(new subblock("", [
            {name: "COMPTON-SUPR-COEFF", default: 0, type:"number", min:0, max:1, description: "Whether to vary alpha during I(Q) fit 0/1 (default: 0)"},
        ]));
    }

    for(let i = 0; i < document.getElementById("nfg").value; i++) {
        sigma_index++;
        master=0;
        if (sigma_index==document.getElementById("lead_series_ind").value)
            master=1;
        blocks.push(new block(" EXP ", [
            {name: "TYPE", default:"EDIFF", type: "text", description: "Type of the experimental set", hidden:true},
            {name: "DATAFILE", default:"", type: "text", status: "M", description: "Name of the data file"},
            {name: "CONST-SUBTRACT", default: 0, type:"number", step: "any", description: "Constant to subtract from the data points (default: 0)"},
            {name: "R-SPACING", default: 0.1, type:"number", step: "any", min:0, description: "Size of the histogram bins in A (default: 0.1)"},
            {name: "USE-RFACTOR", default: 0, type:"number", min:0, max:1, description: "Whether to use R-factor instead of normal chi2 for this set 0/1 (default: 0)"}
        ]));
        if (master==1)
        {
            sigma_name="SIGMA-MASTER";
            sigma_min=SIGMA_MIN_DEF;
        }
        else
        {
            sigma_name="SIGMA"
            sigma_min="any";
        }
        blocks.push(new subblock("", [
            {name: sigma_name, name_s: "SIGMA-SCALABLE", default: SIGMA_DEF, type:"number", step: "any", status: "M", min: sigma_min, description: "Sigma parameter (default: 0.001)"},
        ]));
        blocks.push(new subblock("2", [
            {name: "POINT-RANGE", default: 1, type:"number", min:1, type2:"number", min2:1, description: "First and last data points to use"},           
        ]));
        blocks.push(new subblock("", [
            {name: "RENORM", default: 0, type:"number",  min:0, max:1, description: "Whether to use renormalization coefficient, 0/1 (default: 0)"},
        ]));
        blocks.push(new subblock("4", [ 
            {name: "POLY-BACK-FLAGS", default: 0, type:"number", min:0, max:1, default2: 0, type2:"number", min2:0, max2:1, default3: 0, type3:"number", min3:0, max3:1, default4: 0, type4:"number", min4:0, max4:1, description: "Whether to use polinomial background correction, only offset available 0/1 (default: 0)"},
        ]));
    }


    for(let i = 0; i < document.getElementById("nek").value; i++) {
        sigma_index++;
        master=0;
        if (sigma_index==document.getElementById("lead_series_ind").value)
            master=1;
        blocks.push(new block(" EXP ", [
            {name: "TYPE", default:"EXAFS", type: "text", description: "Type of the experimental set", hidden:true},
            {name: "DATAFILE", default:"", type: "text", status: "M", description: "Name of the data file"},
            {name: "BACKSCATT-FILE",default: "", type:"text", status: "M", description: "Name of the file containing the (k,r)-dependent coefficients "},
            {name: "R-SPACING", default: 0.1, type:"number", step: "any",  min:0, description: "Size of the histogram bins in A (default: 0.1)"},
            {name: "ABSORBER-TYPE",  type:"number",  min:1,status: "M", description: "Type of the absorbing particle for EXAFS"},
            {name: "CHIK-POWER", default: 3, type:"number",  min:1, description: "(k/k_MAX)^CHI-POWER for weighting the EXAFS data (default: 3)"},
            {name: "USE-RFACTOR", default: 0, type:"number", min:0, max:1, description: "Whether to use R-factor instead of normal chi2 for this set 0/1 (default: 0)"}
        ]));
        if (master==1)
        {
            sigma_name="SIGMA-MASTER";
            sigma_min=SIGMA_MIN_DEF;
        }
        else
        {
            sigma_name="SIGMA"
            sigma_min="any";
        }
        blocks.push(new subblock("", [
            {name: sigma_name, name_s: "SIGMA-SCALABLE", default: SIGMA_DEF, type:"number", step: "any", status: "M", min: sigma_min, description: "Sigma parameter (default: 0.001)"},
        ]));
        blocks.push(new subblock("2", [
            {name: "POINT-RANGE", default: 1, type:"number", min:1, type2:"number", min2:1, description: "First and last data points to use"},
            {name: "R-POINT-RANGE", default: 1, type:"number", min:1, type2:"number", min2:1, description: "First and last r-data points to use from the EXAFS (k,r) coefficient file"},
            {name: "DELTAE0_NGRID", default: 0, type:"number", step: "any", min:0, default2: 0, type2:"number", min2:0, description: "Maximum E0-shift in eV and number of k-grid points for the shift in one direction in case of EXAFS(default: 0)"},
        ]));
        blocks.push(new subblock("", [
            {name: "RENORM", default: 0, type:"number",  min:0, max:1, description: "Whether to use renormalization coefficient, 0/1 (default: 0)"},
        ]));
        blocks.push(new subblock("4", [ 
            {name: "POLY-BACK-FLAGS", default: 0, type:"number", min:0, max:1, default2: 0, type2:"number", min2:0, max2:1, default3: 0, type3:"number", min3:0, max3:1, default4: 0, type4:"number", min4:0, max4:1, description: "Whether to use polinomial background correction, only offset available 0/1 (default: 0)"},
        ]));
    }


    for(let i = 0; i < document.getElementById("ncos").value; i++) {
        sigma_index++;
        master=0;
        if (sigma_index==document.getElementById("lead_series_ind").value)
            master=1;
        blocks.push(new block(" COS ", [
            {name: "CENT-TYPE", default:"", type: "number", min:1, max: ntypes, status: "M", description: "Type of central atom"},
            {name: "DISTRIB-TYPE", id: "distrib_type", default:"GAUSSIAN", type: "text", width: "width:140px", description: "Distribution type for cosine distribution constraint, possible values: UNIFORM, GAUSSIAN, ABSENT, filename"},
            {name: "DISTRIB-DEGREES", default:"", type: "number", step: "any", min:0, max: 180, status: "OM", description: "Desired angle in degree"},
            {name: "DISTRIB-WIDTH", default:"", type: "number", step: "any", min:0, status: "OM", description: "Wcontrol parameter"},
        ]));
        blocks.push(new subblock("3", [ 
            {name: "NEIGH-TYPE_FROM_TO", default:"", type: "number", min:1, max: ntypes, status: "M", default2:"", type2: "number", step2: "any", min2:0, status2: "M", default3:"", type3: "number", step3: "any", min3:0, status3: "M", description: "First neighbour atom: Type, minimum and maximum distances in A"},
            {name: "NEIGH-TYPE_FROM_TO", default:"", type: "number", min:1, max: ntypes, status: "M", default2:"", type2: "number", step2: "any", min2:0, status2: "M", default3:"", type3: "number", step3: "any", min3:0, status3: "M", description: "Second neighbour atom: Type, minimum and maximum distances in A"},
        ]));
        if (master==1)
        {
            sigma_name="SIGMA-MASTER";
            sigma_min=SIGMA_MIN_DEF;
        }
        else
        {
            sigma_name="SIGMA"
            sigma_min="any";
        }
        blocks.push(new subblock("", [    
            {name: sigma_name, name_s: "SIGMA-SCALABLE", default: SIGMA_DEF, type:"number", step: "any", status: "M", min: sigma_min, description: "Sigma parameter (default: 0.001)"},
        ]));
       
    }


    for(let i = 0; i < document.getElementById("nic").value; i++) {
        blocks.push(new block(" COORD ", [
            {name: "CENT-TYPE", default:"", type: "number", min:1, max: ntypes, status: "M", description: "Type of central atom"},
                       
        ]));
        for (let j = 0; j< document.getElementById("nicneigh"+i).value; j++)
        {
            blocks.push(new subblock("3", [
                {name: "NEIGH-TYPE_FROM_TO", default:"", type: "number", min:1, max: ntypes, status: "M", default2:"", type2: "number", step2: "any", min2:0, status2: "M", default3:"", type3: "number", step3: "any", min3:0, status3: "M", description: "Neighbour atom: Type, minimum and maximum distances in A"},
            ]));
        }
        for (let j = 0; j< document.getElementById("nicsub"+i).value; j++)
        {
            sigma_index++;
            master=0;
            if (sigma_index==document.getElementById("lead_series_ind").value)
                master=1;
            if (master==1)
            {
                sigma_name="COORDNUM_FRACT_SIGMA-MASTER";
                sigma_min=SIGMA_MIN_DEF;
            }
            else
            {
                sigma_name="COORDNUM_FRACT_SIGMA"
                sigma_min="any";
            }
            blocks.push(new subblock("3", [
                {name: sigma_name, name_s: "COORDNUM_FRACT_SIGMA-SCALABLE", default:"", type: "number", min:0, status: "M", default2:"", type2: "number", step2: "any", min2: 0, max2: 1, status2: "M", default3: SIGMA_DEF, type3: "number", step3: "any", status3: "M", min3: sigma_min, description: "Desired coordination number, fraction and sigma parameter"},
            ]));
        }
    }
   
    for(let i = 0; i < document.getElementById("navc").value; i++) {
        sigma_index++;
        master=0;
        if (sigma_index==document.getElementById("lead_series_ind").value)
            master=1;
        blocks.push(new block(" AVCOORD ", [
            {name: "CENT-TYPE", default:"", type: "number", min: 1, max: ntypes, status: "M", description: "Type of central atom"},
        ]));   
        blocks.push(new subblock("3", [
            {name: "NEIGH-TYPE_FROM_TO", default:"", type: "number", min:1, max: ntypes, status: "M", default2:"", type2: "number", step2: "any", min2:0, status2: "M", default3:"", type3: "number", step3: "any", min3:0, status3: "M", description: "Neighbour atom: Type, minimum and maximum distances in A"},
        ])); 
        if (master==1)
        {
            sigma_name="COORDNUM_SIGMA-MASTER";
            sigma_min=SIGMA_MIN_DEF;
        }
        else
        {
            sigma_name="COORDNUM_SIGMA"
            sigma_min="any";
        }
        blocks.push(new subblock("2", [   
            {name: sigma_name, name_s: "COORDNUM_SIGMA-SCALABLE", default: "", type: "number", min:0, status: "M", default2: SIGMA_DEF, type2: "number", step2: "any", status2: "M", min2: sigma_min, description: "Desired coordination number and sigma parameter"},    
            
        ]));
       
    }

    for(let i = 0; i < document.getElementById("nconc").value; i++) {
        sigma_index++;
        master=0;
        if (sigma_index==document.getElementById("lead_series_ind").value)
            master=1;
        if (master==1)
        {
            sigma_name="COORDNUM_FRACT_SIGMA-MASTER";
            sigma_min=SIGMA_MIN_DEF;
        }
        else
        {
            sigma_name="COORDNUM_FRACT_SIGMA"
            sigma_min="any";
        }
        blocks.push(new block(" CONC ", [
        ]));    
        blocks.push(new subblock("4", [
            {name: "PTYPE1_PTYPE2_FROM_TO", default:"", type: "number",  min: 1, max: ntypes, status: "M", default2:"", type2: "number",  min2: 1, max2: ntypes, status2: "M", default3:"", type3: "number", step3: "any", min3:0, status3: "M", default4:"", type4: "number", step4: "any", min4:0, description: "Type of primary1 and primary2 atoms, minimum and maximum distance in A from each other"},
        ]));
        for (let j = 0; j< document.getElementById("nconcsec"+i).value; j++)
        {
            blocks.push(new subblock("5", [
                {name: "STYPE_FROM1_TO1_FROM2_TO2", default:"", type: "number", min: 1, max: ntypes, status: "M", default2:"", type2: "number", step2: "any", min2:0, status2: "M", default3:"", type3: "number", step3: "any", min3:0, status3: "M", default4:"", type4: "number", step4: "any", min4:0, status4: "M", default5:"", type5: "number", step5: "any", min5:0, status5: "M", description: "Type of secondary atom, minimum and maximum distance in A to P1, to P2."},
            ]));
        }
        blocks.push(new subblock("3", [
            {name: sigma_name, name_s: "COORDNUM_FRACT_SIGMA-SCALABLE", default:"", type: "number", min:0, status: "M", default2:"", type2: "number", step2: "any", min2:0, max2:1, status2: "M", default3: SIGMA_DEF, type3: "number", step3: "any", status3: "M", min3: sigma_min, description: "Desired coordination number, fraction and sigma parameter"},         
        ]));
    }

    for(let i = 0; i < document.getElementById("nsnc").value; i++) 
    {
        sigma_index++;
        master=0;
        if (sigma_index==document.getElementById("lead_series_ind").value)
            master=1;
        if (master==1)
        {
            sigma_name="COORDNUM_FRACT_SIGMA-MASTER";
            sigma_min=SIGMA_MIN_DEF;
        }
        else
        {
            sigma_name="COORDNUM_FRACT_SIGMA"
            sigma_min="any";
        }
        blocks.push(new block(" SNC ", [
        ])); 
        blocks.push(new subblock("4", [  
            {name: "CTYPE_FTYPE_FROM_TO", default:"", type: "number", min:1, max: ntypes, status: "M", default2:"", type2: "number", min2:1, max2: ntypes, status2: "M",default3:"", type3: "number", step3: "any", min3:0, status3: "M", default4:"", type4: "number", step4: "any", min4:0, status4: "M", description: "Type of central and first neighbour atoms, minimum and maximum distance in A from each other"},
        ]));
        for (let j = 0; j< document.getElementById("nsncsec"+i).value; j++)
        {
            blocks.push(new subblock("3", [
                {name: "STYPE_FROM_TO", default:"", type: "number", min:1, max: ntypes, status: "M", default2:"", type2: "number", step2: "any", min2:0, status2: "M", default3:"", type3: "number", step3: "any", min3:0, status3: "M", description: "Type of second neighbour atom, minimum and maximum distance in A to first neighbour"}
            ]));
        }
        blocks.push(new subblock("3", [
            {name: sigma_name, name_s: "COORDNUM_FRACT_SIGMA-SCALABLE", default:"", type: "number", min:0, status: "M", default2:"", type2: "number", step2: "any", min2:0, max2:1, status2: "M", default3: SIGMA_DEF, type3: "number", step3: "any", status3: "M", min3: sigma_min, description: "Desired coordination number, fraction and sigma parameter"},
        ]));
    }

    sigma_pot_index=0;//to find the leading potential series
    if (document.getElementById("NBpot_type").value>0)
    {
        let myname;
        switch (parseInt(document.getElementById("NBpot_type").value))
        {
            case 1: myname="LJ";
                break;
            case 10: myname= "TABULATED";
                break;
        }
        blocks.push(new block(" NBPOT ", [
            {name: "NB-TYPE", default: myname, type: "text", width: "width:140px", description: "Type of the non-bonded potential", hidden: true}
        ]));  
        if (document.getElementById("NBpot_type").value==1)//LJ pot
        {
            
            lead_pot_ind=parseInt(document.getElementById("lead_pot_ind").value);
            blocks.push(new subblock("", [
                {name: "NGR-TYPES", default:document.getElementById("nGR_types").value, type: "number", min: 1, description: "Number of GROMACS types"},
                {name: "LJ-POW", default: 12, type: "number", min: 1, description: "Power of the LJ repulsion term, default: 12"},
                {name: "1-4-SCALE-VDW_COUL", default: 1, type: "number", min: 0, max: 1, step: "any", description: "Scaling factor for the 1-4 vdW and Coulomb interactions, default:1.0 "},
                {name: "CHI-LOWLIMIT-RATIO", default:"NONE", type: "text", min: 0, max: 1, width: "width:140px", description: "The chi2_pot will not decrease under fraction*starting chi2_pot, can give fraction or NONE, default: NONE"},
            ]));
            //LJ parameters according to the combination rule
            let LJ1,LJ2;
            let limit=1,ext_flag=-3,myext;
            let desc1, desc2;
            nGRtypes=parseInt(document.getElementById("nGR_types").value);
            switch (parseInt(document.getElementById("comb_rule").value))
            {
                case 0:
                    LJ1="LJ-C6-EACH";
                    LJ2="LJ-CPOW-EACH";
                    limit=nGRtypes;
                    ext_flag=-2;
                    desc1="LJ first potential parameters in kJ*A^6/mol, used for combination rule=0";
                    desc2="LJ second potential parameter in kJ*A^12/mol, used for combination rule=0";
                    break;
                case 1:
                    LJ1="LJ-C6-GMEAN";
                    LJ2="LJ-CPOW-GMEAN";
                    desc1="LJ first potential parameters in kJ*A^6/mol, used for combination rule=1";
                    desc2="LJ second parameters in kJ*A^6/mol, used for combination rule=1";
                    break;
                case 2:
                    LJ1="LJ-SIG-AMEAN";
                    LJ2="LJ-EPS-GMEAN";
                    desc1="LJ sigma parameters in A, used for combination rule=2";
                    desc2="LJ epsilon parameters in A, used for combination rule=2 and 3";
                    break;
                case 3:
                    LJ1="LJ-SIG-GMEAN";
                    LJ2="LJ-EPS-GMEAN";
                    desc1="LJ sigma parameters in A, used for combination rule=3";
                    desc2="LJ epsilon parameters in A, used for combination rule=2 and 3";
                    break;
            }
            
            for (let i=0;i<limit;i++)//for comb_rule=0 nGRpartials, for the other only nGRtypes parameters exist
            {
                for (let j = i; j < nGRtypes; j++)
                {
                    if (nGRtypes==1)
                    {
                        blocks.push(new subblock("", [
                            {name: LJ1, default: SIGMA_DEF, type: "number", step: "any", status: "M", description: desc1},
                        ]));
                    }
                    else
                    {
                        if (i==0 && j==0)
                        {
                            blocks.push(new subblock("", [
                                {name: LJ1, default: SIGMA_DEF, type: "number", step: "any", status: "M"},
                            ],ext_flag));
                        }
                        else
                        {
                            if (i==nGRtypes-1 && j==nGRtypes-1)
                            {
                                //this can occur only if npartials element exist
                                blocks.push(new subblock("", [
                                    {name: LJ1+(i+1)+"-"+(j+1), default: SIGMA_DEF, type: "number", step: "any", status: "M", description: desc1},
                                ],-1));
                            }
                            else
                            {
                                if (limit==1)
                                    myext=(j+1);
                                else
                                    myext=(i+1)+"-"+(j+1)
                                if (j==nGRtypes-1 && limit==1)//only nGRtypes element, this is the last, write description
                                {
                                    blocks.push(new subblock("", [ 
                                        {name: LJ1+myext, default: SIGMA_DEF, type: "number", step: "any", status: "M", description: desc1},                                       ],-1));
                                }    
                                else                          
                                    blocks.push(new subblock_mid("", [
                                        {name: LJ1+myext, default: SIGMA_DEF, type: "number", step: "any", status: "M"},
                                    ],0));
                                
                            }
                        }
                    }
                } 
            }
            for (let i=0;i<limit;i++)//for comb_rule=0 nGRpartials, for the other only nGRtypes parameters exist
            {
                for (let j = i; j < nGRtypes; j++)
                {
                    if (nGRtypes==1)
                    {
                        blocks.push(new subblock("", [
                            {name: LJ2, default: SIGMA_DEF, type: "number", step: "any", status: "M", description: "LJ second potential parameter in kJ*A^12/mol, used for combination rule=0, see the manual"},
                        ]));
                    }
                    else
                    {
                        if (i==0 && j==0)
                        {
                            blocks.push(new subblock("", [
                                {name: LJ2, default: SIGMA_DEF, type: "number", step: "any", status: "M"},
                            ],ext_flag));
                        }
                        else
                        {
                            if (i==nGRtypes-1 && j==nGRtypes-1)
                            {
                                //this can occur only if npartials element exist
                                blocks.push(new subblock("", [
                                    {name: LJ2+(i+1)+"-"+(j+1), default: SIGMA_DEF, type: "number", step: "any", status: "M", description: "LJ second potential parameter in kJ*A^12/mol, used for combination rule=0, see the manual"},
                                ],-1));
                            }
                            else
                            {
                                if (limit==1)
                                    myext=(j+1);
                                else
                                    myext=(i+1)+"-"+(j+1)
                                if (j==nGRtypes-1 && limit==1)//only nGRtypes element, this is the last, write description
                                {
                                    blocks.push(new subblock("", [ 
                                        {name: LJ2+myext, default: SIGMA_DEF, type: "number", step: "any", status: "M", description: desc2},                                       ],-1));
                                }   
                                else             
                                    blocks.push(new subblock_mid("", [
                                        {name: LJ2+myext, default: SIGMA_DEF, type: "number", step: "any", status: "M"},
                                    ],0));
                                    
                            }
                        }
                    }
                } 
            }

            blocks.push(new subblock("2", [
                {name: "CUTOFF-VDW_COUL", default: 5, type: "number", min: 0, step: "any", default2: 5, type2: "number", min2: 0, step2: "any", description: "Cutoff for the vdW and Coulomb interactions in A"},
            ]));
            //sigma parameters according to the weight mode
            //vdW
            switch (parseInt(document.getElementById("weight_mode").value))
            {
                case 0:
                    sigma_pot_index=2;//total number of NB for chi2, for NB lead will not be determined here, only needed if flexible mols are present
                    blocks.push(new subblock("", [
                        {name: "VDW-SIGMA", default: SIGMA_DEF, type: "number", step: "any", status: "M", description: "Weight parameter for the vdW interaction"},
                        {name: "COUL-SIGMA", default: SIGMA_DEF, type: "number", step: "any", status: "M", description: "Weight parameter for the Coulomb interaction"},              
                    ]));
                    break;
                case 1:
                    sigma_pot_index=2*npartials;//total number of NB for chi2, for NB lead will not be determined here, only needed if flexible mols are present
                    for (let i=0;i<ntypes;i++)//npartials sigma values
                    {
                        for (let j = i; j < ntypes; j++)
                        {
                            if (ntypes==1)
                            {
                                blocks.push(new subblock("", [
                                    {name: "VDW-SIGMA", default: SIGMA_DEF, type: "number", step: "any", status: "M", description: "Weight parameter for the vdW interaction"},
                                ]));
                            }
                            else
                            {
                                if (i==0 && j==0)
                                {
                                    blocks.push(new subblock("", [
                                        {name: "VDW-SIGMA", default: SIGMA_DEF, type: "number", step: "any", status: "M"},
                                    ],-2));
                                }
                                else
                                {
                                    if (i==ntypes-1 && j==ntypes-1)
                                    {
                                        blocks.push(new subblock("", [
                                            {name: "VDW-SIGMA"+(i+1)+"-"+(j+1), default: SIGMA_DEF, type: "number", step: "any", status: "M", description: "Weight parameters for the vdW interactions"},
                                        ],-1));
                                    }
                                    else
                                    {
                                        blocks.push(new subblock_mid("", [
                                            {name: "VDW-SIGMA"+(i+1)+"-"+(j+1), default: SIGMA_DEF, type: "number", step: "any", status: "M"},
                                        ],0));
                                    }
                                }
                            }
                        } 
                    }
                    for (let i=0;i<ntypes;i++)//npartials sigma values
                    {
                        for (let j = i; j < ntypes; j++)
                        {
                            if (ntypes==1)
                            {
                                blocks.push(new subblock("", [
                                    {name: "COUL-SIGMA", default: SIGMA_DEF, type: "number", step: "any", status: "M", description: "Weight parameter for the Coulomb interaction"},
                                ]));
                            }
                            else
                            {
                                if (i==0 && j==0)
                                {
                                    blocks.push(new subblock("", [
                                        {name: "COUL-SIGMA", default: SIGMA_DEF, type: "number", step: "any", status: "M"},
                                    ],-2));
                                }
                                else
                                {
                                    if (i==ntypes-1 && j==ntypes-1)
                                    {
                                        blocks.push(new subblock("", [
                                            {name: "COUL-SIGMA"+(i+1)+"-"+(j+1), default: SIGMA_DEF, type: "number", step: "any", status: "M", description: "Weight parameters for the Coulomb interactions"},
                                        ],-1));
                                    }
                                    else
                                    {
                                        blocks.push(new subblock_mid("", [
                                            {name: "COUL-SIGMA"+(i+1)+"-"+(j+1), default: SIGMA_DEF, type: "number", step: "any", status: "M"},
                                        ],0));
                                    }
                                }
                            }
                        } 
                    }
                    break;
                case 2:
                    sigma_pot_index=2;//total number of NB for chi2, for NB lead will not be determined here, only needed if flexible mols are present
                    blocks.push(new subblock("", [
                        {name: "SIGMA-OVERALLPOT", default: SIGMA_DEF, type: "number", step: "any", status: "M", description: "Weight parameter for the potential interactions"},
                    ]));
                    break;
                
            }
        }
        else//tabulated pot
        {
            let desc;
            lead_pot_ind=parseInt(document.getElementById("lead_pot_ind").value);
            blocks.push(new subblock("", [
                {name: "CUTOFF-TAB", default: 5, type: "number", min: 0, step: "any", description: "Cutoff for the tabulated interactions in A"},
                {name: "TEMPERATURE", default: 5, type: "number", min: 0, step: "any", description: "Temperature in K, no algorithmic meaning, for tabulated potential"},
            ]));
            
            for (let i=0;i<document.getElementById("ntab_pot").value;i++)
            {
                //even the pot leadind series can be scaled
                sigma_pot_index++;
                if (sigma_pot_index==document.getElementById("lead_pot_ind").value)
                {
                    sigma_name="IND_SIGMA-MASTER_FILE";
                    desc="The index of the partial for this tabulated potential, sigma, file name with tabulated potential";
                }
                else
                {
                    sigma_name="IND_SIGMA_FILE";//can be normal or scalable, only decided at save
                    desc="The index of the partial for this tabulated potential, lead potential sigma, file name with tabulated potential";
                }

                blocks.push(new subblock("3", [
                    {name: sigma_name, name_s: "IND_SIGMA-SCALABLE_FILE",  status: "M", default: 5, type: "number", min: 1, max: npartials, type2: "number", step2: "any", status2: "M", default2: SIGMA_DEF, min2: "any", type3: "text", default3: "", status3: "M",  description: desc},
                ]));
                
            }

        }
    }
    if (document.getElementById("is_bonded").value==1)
    {
        let mysigma_index;
        let mylead;
        blocks.push(new block(" BPOT ", [
            {name: "COMP-OPTION", default:"NONE", type: "text", description: "A compiler option to use during the reading of the topology file, there can be more, than one, default: NONE"},
        ]));
        if (document.getElementById("NBpot_type").value>0)
        {
            mysigma_index=sigma_pot_index;//contribute to chi2pot, lead_pot_ind is relevant
            mylead="lead_pot_ind";
        }
        else//contributes to normal chi2
        {
            mysigma_index=sigma_index;//contribute to normal chi2, lead_series_ind is relevant
            mylead="lead_series_ind";
        }

        sigma_name="";
        master=0;
        for(let i = 0; i < document.getElementById("nbond").value; i++) 
        {
            mysigma_index++;
            if (mysigma_index==document.getElementById(mylead).value)
            {
                master=i+1;//this is the index of the lead bond in its own type
                sigma_name="LEAD-BOND";
                                    
            }
        }

        if (sigma_name=="")
        {
            for(let i = 0; i < document.getElementById("nangle").value; i++) 
            {
                mysigma_index++;
                if (mysigma_index==document.getElementById(mylead).value)
                {
                    master=i+1;//this is the index of the lead angle in its own type
                    sigma_name="LEAD-ANGLE";
                                        
                }
            }
        }
 
        if (sigma_name=="")
        {
            for(let i = 0; i < document.getElementById("nperdih").value; i++) 
            {
                mysigma_index++;
                if (mysigma_index==document.getElementById(mylead).value)
                {
                    master=i+1;//this is the index of the lead periodic dihedral in its own type
                    sigma_name="LEAD-PERDIH";
                                        
                }
            }
        }
     
        if (sigma_name=="")
        {
            for(let i = 0; i < document.getElementById("nharmdih").value; i++) 
            {
                mysigma_index++;
                if (mysigma_index==document.getElementById(mylead).value)
                {
                    master=i+1;//this is the index of the lead harmonic dihedral in its own type
                    sigma_name="LEAD-HARMDIH";
                                        
                }
            }
        }
  
        if (sigma_name=="")
        {
            for(let i = 0; i < document.getElementById("nRBdih").value; i++) 
            {
                mysigma_index++;
                if (mysigma_index==document.getElementById(mylead).value)
                {
                    master=i+1;//this is the index of the lead RB dihedral in its own type
                    sigma_name="LEAD-RBDIH";
                                        
                }
            }
        }
     
        if (sigma_name!="")
        {
            blocks.push(new subblock("", [
                {name: sigma_name, default:master, type: "number", description: "The index of the leading potential interaction in its own type ", hidden:true}
            ]));
        }
    }
    CheckLeadIndTot(0);
    if (document.getElementById("NBpot_type").value>0)
        CheckLeadPotIndTot(0);
    document.getElementById("save_button").hidden=false;
    document.getElementById("new_button").hidden=false;

    document.getElementById("options").innerHTML = "";
    

   
}

function NewData()
{
    if (confirm("Are you sure that you want to leave this page and start a new data input?\nAll the data will be lost!"))
    {
        location.reload(true);
    }
   
    
}


function AddSub(who, whereto1,whereto2) {
    if (nic_prev<document.getElementById(who).value)
            ndata_tot++;
        else
            if (nic_prev>document.getElementById(who).value)
                ndata_tot--;
    
    nic_prev=document.getElementById(who).value;
    nicsub_prev=nic_prev;
    
    document.getElementById(whereto1).innerHTML="";
    for(let i = 0; i < document.getElementById(who).value; i++) {
        blocks.push(new smallBlock(whereto1, [
            {name: "Constraint"+(i+1),id: whereto1+i, default:"1", type: "number", min: 1, description: "Number of neighbour types"},
        ]));
        
    }
    document.getElementById(whereto2).innerHTML="";
    for(let i = 0; i < document.getElementById(who).value; i++) {
        let mycall="UpdateTot('"+whereto2+i+"')";
        blocks.push(new smallBlock(whereto2, [
            {name: "Constraint"+(i+1),id: whereto2+i, default:"1", type: "number", min: 1, description: "Number of subconstraints", oninput: mycall},
        ]));
        
    }
    
    nlead_tot=ndata_tot;   
    if (document.getElementById("is_bonded").value==1)
        nlead_tot+=nbonded_tot;
    CheckLeadIndTot(0);
    document.getElementById("lead_tot_space").innerHTML="";
    blocks.push(new smallBlock("lead_tot_space", [
        {id:"lead_tot", type: "text", default: nlead_tot, width_inp: "width:140px", align: "left", hidden:true},
    ],-1));
}

function AddNeighs(who, whereto) {
    var my_desc="subblocks";
    
    if (whereto=="nconcsec")
    {
        if (nconc_prev<document.getElementById(who).value)
            ndata_tot++;
        else
            if (nconc_prev>document.getElementById(who).value)
                ndata_tot--;
        nconc_prev=document.getElementById(who).value;
        my_desc="Number of secondary types";
    }
    if (whereto=="nsncsec")
    {
        if (nsnc_prev<document.getElementById(who).value)
            ndata_tot++;
        else
            if (nsnc_prev>document.getElementById(who).value)
                ndata_tot--;
        nsnc_prev=document.getElementById(who).value;
        my_desc="Number of second neighbour types";
    }
    
    document.getElementById(whereto).innerHTML="";
    for(let i = 0; i < document.getElementById(who).value; i++) {
        blocks.push(new smallBlock(whereto, [
            {name: "Constraint"+(i+1),id: whereto+i, default:"1", type: "number", min: 1, description: my_desc},
        ]));
    }
    nlead_tot=ndata_tot;  
    if (document.getElementById("is_bonded").value==1)
        nlead_tot+=nbonded_tot;
    CheckLeadIndTot(0);
     
    document.getElementById("lead_tot_space").innerHTML="";
    blocks.push(new smallBlock("lead_tot_space", [
        {id:"lead_tot", type: "text", default: nlead_tot, width_inp: "width:140px", align: "left", hidden:true},
    ],-1));
}

function CheckNB()
{
    ntypes=parseInt(document.getElementById("ntypes").value);
    npartials=ntypes*(ntypes+1)/2;
    document.getElementById("NB_sub").innerHTML="";
    if (!(document.getElementById("NBpot_type").value==0 || document.getElementById("NBpot_type").value==1 || document.getElementById("NBpot_type").value==10))
    {
        alert("Presently only 0: no potential, 1: LJ and 10: tabulated potential can be chosen!");
        document.getElementById("NBpot_type").value=0;
        
    }
    if (document.getElementById("NBpot_type").value==1)
    {
        document.getElementById("NB_sub").innerHTML="";
        blocks.push(new smallBlock("NB_sub", [
            {name: "Leading potential interaction index", id: "lead_pot_ind", default:"1", type: "number", min: 1, width: "width:200px", oninput: "CheckLeadPotIndTot()"},
            {name: "Number of GROMACS types", id: "nGR_types", default:"1", type: "number", min: 1, width: "width:200px"},
            {name: "Combination rule", id: "comb_rule", default:"0", type: "number", min: 0, max: 3, width: "width:200px"},
            {name: "Weight mode", id: "weight_mode", default:"2", type: "number", min: 0, max: 2, width: "width:200px", oninput: "UpdateNB()"},
        ]));
        nNB_tot=2;//as weight mode def is 2, meaning 1 for vdW and 1 for Coulomb
    }
    else
    {
        if (document.getElementById("NBpot_type").value==10)
        {
            document.getElementById("NB_sub").innerHTML="";
            blocks.push(new smallBlock("NB_sub", [
                {name: "Number of tabulated potential files", id: "ntab_pot",  type: "number", default:"1", min: 1,  max: npartials},
                {name: "Leading potential interaction index", id: "lead_pot_ind", default:"1", type: "number", min: 1, width: "width:200px"},
            ]));
            nNB_tot=1;//there is at least 1 tabulated potential
        }
    }
    if (document.getElementById("NBpot_type").value>0)//lead chi2pot is calculated, if there are bonded interactions, they will contribute to that instead of norma
    {
        if (document.getElementById("is_bonded").value==1)
        {
            nlead_tot=ndata_tot;  
            npotser_tot=nNB_tot+nbonded_tot;//bonded contributes to chi2pot
        }
        else
            npotser_tot=nNB_tot;
    }
    else
    {
        //there is no chi2pot
        npotser_tot=0;
        if (document.getElementById("is_bonded").value==1)
        {
            nlead_tot=ndata_tot+nbonded_tot;  //bonded contributes to normal
           
        }
        else
            nlead_tot=ndata_tot;
    }
    document.getElementById("lead_tot_space").innerHTML="";
    blocks.push(new smallBlock("lead_tot_space", [
        {id:"lead_tot", type: "text", default: nlead_tot, width_inp: "width:140px", align: "left", hidden:true},
    ],-1));
    document.getElementById("leadpot_tot_space").innerHTML="";
    blocks.push(new smallBlock("leadpot_tot_space", [
        {id:"leadpot_tot", type: "text", default: npotser_tot, width_inp: "width:140px", align: "left", hidden:true},
    ],-1));
    CheckLeadIndTot(0);
    CheckLeadPotIndTot();
    
}
function UpdateNB()
{
    ntypes=parseInt(document.getElementById("ntypes").value);
    npartials=ntypes*(ntypes+1)/2;
    if (document.getElementById("weight_mode").value==1)
        nNB_tot=2*npartials;
    else
        nNB_tot=2;
        
    npotser_tot=nNB_tot+nbonded_tot;
    CheckLeadPotIndTot();
    document.getElementById("leadpot_tot_space").innerHTML="";
    blocks.push(new smallBlock("leadpot_tot_space", [
        {id:"leadpot_tot", type: "text", default: npotser_tot, width_inp: "width:140px", align: "left", hidden:true},
    ],-1));  
}
function CheckBonded()
{
    var myname;
    var myid;
    var mycall;
    //this works somewhat similary as the COORD subconstraints
    //but here only 0 and 1 is possibel, and the number of interaction types is fixed
    if (is_bonded_prev>document.getElementById("is_bonded").value)//it is switched of
    {
            nbonded_tot=0;
            if (document.getElementById("NBpot_type").value==0)
            {
                //contributes to normal chi2
                nlead_tot=ndata_tot;   
                document.getElementById("lead_tot_space").innerHTML="";
                blocks.push(new smallBlock("lead_tot_space", [
                    {id:"lead_tot", type: "text", default: nlead_tot, width_inp: "width:140px", align: "left", hidden:true},
                ],-1));
               
            } 
            else
            {
                npotser_tot=nNB_tot;  
                document.getElementById("leadpot_tot_space").innerHTML="";
                blocks.push(new smallBlock("leadpot_tot_space", [
                    {id:"leadpot_tot", type: "text", default: npotser_tot, width_inp: "width:140px", align: "left", hidden:true},
                ],-1));
            }
                
    }
  
    is_bonded_prev=document.getElementById("is_bonded").value;
    if (document.getElementById("is_bonded").value==0)
    {
        nbond_prev=0;
        nangle_prev=0;
        nperdih_prev=0;
        nharmdih_prev=0;
        nRBdih_prev=0;
     }

    document.getElementById("bondedint_type").innerHTML="";
    if (document.getElementById("is_bonded").value==1)
    {
        for(let i = 0; i < 5; i++) {
            switch (i)
            {
                case 0:
                    myid="nbond";
                    myname="Number of bond types with separate sigma:";
                    break; 
                case 1:
                    myid="nangle";
                    myname="Number of angle types with separate sigma:";
                    break; 
                case 2:
                    myid="nperdih";
                    myname="Number of periodic dih. types with separate sigma:";
                    break;
                case 3:
                    myid ="nharmdih";
                    myname="Number of harmonic dih. types with separate sigma:";
                    break;  
                case 4:
                    myid = "nRBdih";
                    myname="Number of RB dih. types with separate sigma:";
                    break; 
            }
            mycall="CalcBonded('"+myid+"')";
            blocks.push(new smallBlock("bondedint_type", [
                {name: myname, id:myid, default:"0", type: "number", min: 0, width: "width:200px", oninput: mycall},
            ]));
            
        }
    }
    CheckLeadIndTot(0);
    CheckLeadPotIndTot(0);
}

function UpdateTot(who) {
    var myid;
    var tot_subconst=0;
    if (who=="ngr")
    {
        if (ngr_prev<document.getElementById(who).value)
            ndata_tot++;
        else
        {
            if (ngr_prev>document.getElementById(who).value)
                ndata_tot--;
        }
        ngr_prev=document.getElementById(who).value;
    }
    if (who=="nsq")
    {
        if (nsq_prev<document.getElementById(who).value)
            ndata_tot++;
        else
            if (nsq_prev>document.getElementById(who).value)
                ndata_tot--;
        nsq_prev=document.getElementById(who).value;
    }
    if (who=="nfq")
    {
        if (nfq_prev<document.getElementById(who).value)
            ndata_tot++;
        else
            if (nfq_prev>document.getElementById(who).value)
                ndata_tot--;
        nfq_prev=document.getElementById(who).value;
    }
    if (who=="nfg")
    {
        if (nfg_prev<document.getElementById(who).value)
            ndata_tot++;
        else
            if (nfg_prev>document.getElementById(who).value)
                ndata_tot--;
        nfg_prev=document.getElementById(who).value;    
    }
    if (who=="nek")
    {
        if (nek_prev<document.getElementById(who).value)
            ndata_tot++;
        else
            if (nek_prev>document.getElementById(who).value)
                ndata_tot--;
        nek_prev=document.getElementById(who).value;
    }
    if (who=="ncos")
    {
        if (ncos_prev<document.getElementById(who).value)
            ndata_tot++;
        else
            if (ncos_prev>document.getElementById(who).value)
                ndata_tot--;
        ncos_prev=document.getElementById(who).value;
    }
    for (let i=0; i<document.getElementById("nic").value;i++)
    {
        
        myid="nicsub"+i.toString();
        tot_subconst+=parseInt(document.getElementById(myid).value);//this will be the actual total number of the COORD subconstarint
    }
  
    for (let i=0; i<document.getElementById("nic").value;i++)
    {
        myid="nicsub"+i.toString();
        if (who==myid)
        {
            if (nicsub_prev<tot_subconst)
                ndata_tot++;
            else
                if (nicsub_prev>tot_subconst)
                    ndata_tot--;
            nicsub_prev=tot_subconst;
        }
    }
    if (who=="navc")
    {
        if (nac_prev<document.getElementById(who).value)
            ndata_tot++;
        else
            if (nac_prev>document.getElementById(who).value)
                ndata_tot--;
        nac_prev=document.getElementById(who).value;
    }
    nlead_tot=ndata_tot;
    if (document.getElementById("is_bonded").value==1)
        nlead_tot+=nbonded_tot;
    
    CheckLeadIndTot(0);
    document.getElementById("lead_tot_space").innerHTML="";
    blocks.push(new smallBlock("lead_tot_space", [
        {id:"lead_tot", type: "text", default: nlead_tot, width_inp: "width:140px", align: "left", hidden:true},
    ],-1));
    
}

function CalcBonded(who)
{
    var myprev=0;
    if (document.getElementById("is_bonded").value==1)
    {
        switch (who)
        {
            case "nbond":
                myprev=nbond_prev;
                break; 
            case "nangle":
                myprev=nangle_prev;
                break; 
            case "nperdih":
                myprev=nperdih_prev;
                break;
            case "nharmdih":
                myprev=nharmdih_prev;
                break;  
            case "nRBdih":
                myprev=nRBdih_prev;
                break; 
        }
       
        if (myprev<document.getElementById(who).value)
        {
            nbonded_tot++;
          
        }
        else
        {
            if (myprev>document.getElementById(who).value)
            {
                nbonded_tot--;
            }
        }
        switch (who)
        {
            case "nbond":
                nbond_prev=document.getElementById(who).value;
                break; 
            case "nangle":
                nangle_prev=document.getElementById(who).value;
                break; 
            case "nperdih":
                nperdih_prev=document.getElementById(who).value;
                break;
            case "nharmdih":
                nharmdih_prev=document.getElementById(who).value;
                break;  
            case "nRBdih":
                nRBdih_prev=document.getElementById(who).value;
                break; 
        }
        
        
    }
    if (document.getElementById("NBpot_type").value==0)
    {
        nlead_tot=ndata_tot+nbonded_tot;
        CheckLeadIndTot(0);
        CheckLeadPotIndTot(0);
        document.getElementById("lead_tot_space").innerHTML="";
        blocks.push(new smallBlock("lead_tot_space", [
            {id:"lead_tot", type: "text", default: nlead_tot, width_inp: "width:140px", align: "left", hidden:true},
        ],-1));
    }
    else
    {
        npotser_tot=nNB_tot+nbonded_tot;
        CheckLeadPotIndTot(0);
        alert(npotser_tot+" NB "+nNB_tot+" bonded "+nbonded_tot);
        document.getElementById("leadpot_tot_space").innerHTML="";
        blocks.push(new smallBlock("leadpot_tot_space", [
            {id:"leadpot_tot", type: "text", default: npotser_tot, width_inp: "width:140px", align: "left", hidden:true},
        ],-1));
    }
   
}

function CheckLeadIndTot(is_reset_field=1) {
    var mytext="The lead series is the ";
    var sum=0,index=0;
    var myid;
    var cont=1;
    if (document.getElementById("lead_series_ind").value>nlead_tot)
    {
        alert("The lead series index cannot exceed the total number of data sets and constraints, which is "+nlead_tot);
        if (nlead_tot==0)
        {
            document.getElementById("lead_series_ind").value=0;
            mytext="";
        }
        else
            document.getElementById("lead_series_ind").value=1;

    }
    if (is_reset_field==1)
        SetEmptyFields();
    //determining which is chosen for lead series
    if (document.getElementById("lead_series_ind").value=="" || document.getElementById("lead_series_ind").value==0)
    {
        if (nlead_tot==0)
        {
            document.getElementById("lead_series_ind").value=0;
            mytext="Lead series is not set";
        }
        else
            document.getElementById("lead_series_ind").value=1;
    }
   
    if (nlead_tot==0 || document.getElementById("lead_series_ind").value==0)
    {
        mytext="Lead series is not set";
    }
    else
    {
        sum=parseInt(document.getElementById("ngr").value);
        if (document.getElementById("lead_series_ind").value<=sum) 
        {
            mytext+=document.getElementById("lead_series_ind").value+". GR series";
            
        }
        else 
        {

            if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("nsq").value))
            {
                index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                mytext+=index.toString()+". ND series";
                
            }
            else 
            {
                sum+=parseInt(document.getElementById("nsq").value);
                if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("nfq").value))
                {
                    index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                    mytext+=index.toString()+". XRD series";
                    
                }
                else 
                {
                    sum+=parseInt(document.getElementById("nfq").value);
                    if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("nfg").value))
                    {
                        index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                        mytext+=index.toString()+". EDIFF series";
                        
                    }
                    else 
                    {
                        sum+=parseInt(document.getElementById("nfg").value);
                        if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("nek").value))
                        {
                            index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                            mytext+=index.toString()+". EXAFS series";
                            
                        }
                        else 
                        {
                            sum+=parseInt(document.getElementById("nek").value);
                            if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("ncos").value))
                            {
                                index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                                mytext+=index.toString()+". COS constraint";
                                
                            }
                            else 
                            {
                                sum+=parseInt(document.getElementById("ncos").value);
                                for (let i=0;i<document.getElementById("nic").value;i++)
                                {
                                    if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("nicsub"+i.toString()).value))
                                    {
                                        index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                                        let index2=parseInt(i)+1;
                                        mytext+=index.toString()+". subconstraint of the "+index2.toString()+". COORD constraint";
                                        cont=0;
                                        break;
                                    
                                    }
                                    sum+=parseInt(document.getElementById("nicsub"+i.toString()).value);
                                }
                                if (cont)
                                {
                                    let index2=parseInt(document.getElementById("nic").value)-1;
                                    if (index2>0)//there is a COORD
                                    {
                                        myid="nicsub"+index2.toString();
                                        sum+=parseInt(document.getElementById(myid).value);
                                    }
                                    if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("navc").value))
                                    {
                                        index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                                        mytext+=index.toString()+". AVCOORD constraint";
                                        
                                    }
                                    else
                                    {
                                        sum+=parseInt(document.getElementById("navc").value);
                                        if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("nconc").value))
                                        {
                                            index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                                            mytext+=index.toString()+". CONC constraint";
                                            
                                        }
                                        else
                                        {
                                            sum+=parseInt(document.getElementById("nconc").value);
                                            if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("nsnc").value))
                                            {
                                                index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                                                mytext+=index.toString()+". SNC constraint";
                                                
                                            }
                                            else
                                            {
                                                if (document.getElementById("is_bonded").value==1)
                                                {
                                                    sum+=parseInt(document.getElementById("nsnc").value);
                                                    if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("nbond").value))
                                                    {
                                                        index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                                                        mytext+=index.toString()+". bond interaction";
                                                        
                                                    }
                                                    else
                                                    {
                                                        sum+=parseInt(document.getElementById("nbond").value);
                                                        if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("nangle").value))
                                                        {
                                                            index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                                                            mytext+=index.toString()+". angle interaction";
                                                            
                                                        }  
                                                        else
                                                        {
                                                            sum+=parseInt(document.getElementById("nangle").value);
                                                            if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("nperdih").value))
                                                            {
                                                                index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                                                                mytext+=index.toString()+". periodic dihedral interaction";
                                                                
                                                            }
                                                            else
                                                            {
                                                                sum+=parseInt(document.getElementById("nperdih").value);
                                                                if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("nharmdih").value))
                                                                {
                                                                    index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                                                                    mytext+=index.toString()+". harmonic dihedral interaction";
                                                                    
                                                                }
                                                                else
                                                                {
                                                                    sum+=parseInt(document.getElementById("nharmdih").value);
                                                                    if (document.getElementById("lead_series_ind").value<=parseInt(sum)+parseInt(document.getElementById("nRBdih").value))
                                                                    {
                                                                        index=parseInt(document.getElementById("lead_series_ind").value) - sum;
                                                                        mytext+=index.toString()+". RB dihedral interaction";
                                                                        
                                                                    }  
                                                                }  
                                                            }  
                                                        }
                                                    }
                                                }
                                                
                                            }
                                        }
                                    }
                                }
                            }  
                        }  
                    }  
                }    
            }
        }
    }

    document.getElementById("lead_text_space").innerHTML="";
    blocks.push(new smallBlock("lead_text_space", [
        {name: mytext, id: "lead_text", type: "text",  hidden:true},
    ],1));
    
}

function CheckLeadPotIndTot(is_reset_field=1) {
    var mytext="The lead potential series is the ";
    var sum=0,index=0;
    
    if (document.getElementById("NBpot_type").value>0)
    {
        if (document.getElementById("lead_pot_ind").value>npotser_tot)
        {
            alert("The lead potential interaction index cannot exceed the total number of bonded and non-bonded interactions, which is "+npotser_tot);
            if (npotser_tot==0)
            {
                document.getElementById("lead_pot_ind").value=0;
                mytext="";
            }
            else
                document.getElementById("lead_pot_ind").value=1;

        }
    }
   
    if (is_reset_field==1)
        SetEmptyFields();
    //determining which is chosen for lead series
    if (document.getElementById("NBpot_type").value>0)
    {
        if (document.getElementById("lead_pot_ind").value=="" || document.getElementById("lead_pot_ind").value==0)
        {
            if (npotser_tot==0)
            {
                //this cannot happen
                document.getElementById("lead_pot_ind").value=0;
                mytext="Lead potential interaction is not set";
            }
            else
                document.getElementById("lead_pot_ind").value=1;
        }
   
    
        ntypes=parseInt(document.getElementById("ntypes").value);
        npartials=ntypes*(ntypes+1)/2;
        if (document.getElementById("weight_mode").value==1)
            nNB_tot=2*npartials;
        else
            nNB_tot=2;
            
        npotser_tot=nNB_tot+nbonded_tot;
        if (npotser_tot==0 || document.getElementById("lead_pot_ind").value==0)
        {
            mytext="Lead potential series is not set";
        }
        else
        {
            sum=nNB_tot/2;
            if (document.getElementById("lead_pot_ind").value<=parseInt(sum))
            {
                index=parseInt(document.getElementById("lead_pot_ind").value);
                mytext+=index.toString()+". vdW interaction";
                
            }
            else
            {
                if (document.getElementById("lead_pot_ind").value<=parseInt(sum)+nNB_tot/2)
                {
                    index=parseInt(document.getElementById("lead_pot_ind").value) - sum;
                    mytext+=index.toString()+". Coulomb interaction";
                    
                }
                else
                {
                    if (document.getElementById("is_bonded").value==1)
                    {
                        sum+=nNB_tot/2;
                        if (document.getElementById("lead_pot_ind").value<=parseInt(sum)+parseInt(document.getElementById("nbond").value))
                        {
                            index=parseInt(document.getElementById("lead_pot_ind").value) - sum;
                            mytext+=index.toString()+". bond interaction";
                            
                        } 
                        else
                        {
                            sum+=parseInt(document.getElementById("nbond").value);
                            if (document.getElementById("lead_pot_ind").value<=parseInt(sum)+parseInt(document.getElementById("nangle").value))
                            {
                                index=parseInt(document.getElementById("lead_pot_ind").value) - sum;
                                mytext+=index.toString()+". angle interaction";
                                
                            } 
                            else
                            {
                                sum+=parseInt(document.getElementById("nangle").value);
                                if (document.getElementById("lead_pot_ind").value<=parseInt(sum)+parseInt(document.getElementById("nperdih").value))
                                {
                                    index=parseInt(document.getElementById("lead_pot_ind").value) - sum;
                                    mytext+=index.toString()+". periodic dihedral interaction";
                                    
                                } 
                                else
                                {
                                    sum+=parseInt(document.getElementById("nperdih").value);
                                    if (document.getElementById("lead_pot_ind").value<=parseInt(sum)+parseInt(document.getElementById("nharmdih").value))
                                    {
                                        index=parseInt(document.getElementById("lead_pot_ind").value) - sum;
                                        mytext+=index.toString()+". harmonic dihedral interaction";
                                        
                                    } 
                                    else
                                    {
                                        sum+=parseInt(document.getElementById("nharmdih").value);
                                        if (document.getElementById("lead_pot_ind").value<=parseInt(sum)+parseInt(document.getElementById("nRBdih").value))
                                        {
                                            index=parseInt(document.getElementById("lead_pot_ind").value) - sum;
                                            mytext+=index.toString()+". RB dihedral interaction";
                                            
                                        } 
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }
    else
        mytext="There is no chi2pot, lead potential interaction is not needed";
  
    document.getElementById("leadpot_text_space").innerHTML="";
    blocks.push(new smallBlock("leadpot_text_space", [
        {name: mytext, id: "leadpot_text", type: "text",  hidden:true},
    ],1));
    
}

function SetEmptyFields()
{
    //set the empty ones to 0
    if (document.getElementById("ngr").value=="")
        document.getElementById("ngr").value=0;
    if (document.getElementById("nsq").value=="")
        document.getElementById("nsq").value=0;
    if (document.getElementById("nfq").value=="")
        document.getElementById("nfq").value=0;
    if (document.getElementById("nfg").value=="")
        document.getElementById("nfg").value=0;
    if (document.getElementById("nek").value=="")
        document.getElementById("nek").value=0;
    if (document.getElementById("ncos").value=="")
        document.getElementById("ncos").value=0;
    if (document.getElementById("nic").value=="")
        document.getElementById("nic").value=0;
    if (document.getElementById("navc").value=="")
        document.getElementById("navc").value=0;
    if (document.getElementById("nconc").value=="")
        document.getElementById("nconc").value=0;
    if (document.getElementById("nsnc").value=="")
        document.getElementById("nsnc").value=0;
    if (document.getElementById("is_bonded").value=="")
        document.getElementById("is_bonded").value=0;
    if (document.getElementById("NBpot_type").value=="")
        document.getElementById("NBpot_type").value=0;
    for (let i=0;i<document.getElementById("nic").value;i++)
    {
        if (document.getElementById("nicneigh"+i).value=="")
            document.getElementById("nicneigh"+i).value=1;
        if (document.getElementById("nicsub"+i).value=="")
            document.getElementById("nicsub"+i).value=1;

    }
    for (let i=0;i<document.getElementById("nconc").value;i++)
    {
        if (document.getElementById("nconcsec"+i).value=="")
            document.getElementById("nconcsec"+i).value=1;
    }
    for (let i=0;i<document.getElementById("nsnc").value;i++)
    {
        if (document.getElementById("nsncsec"+i).value=="")
            document.getElementById("nsncsec"+i).value=1;
    }
    if (document.getElementById("is_bonded").value==1)
    {
        if (document.getElementById("nbond").value=="")
            document.getElementById("nbond").value=0;
        if (document.getElementById("nangle").value=="")
            document.getElementById("nangle").value=0;
        if (document.getElementById("nperdih").value=="")
            document.getElementById("nperdih").value=0;
        if (document.getElementById("nharmdih").value=="")
            document.getElementById("nharmdih").value=0;
        if (document.getElementById("nRBdih").value=="")
            document.getElementById("nRBdih").value=0;
    }
    if (document.getElementById("NBpot_type").value==1)
    {
        if (document.getElementById("nGR_types").value=="")
            document.getElementById("nGR_types").value=0;
        if (document.getElementById("comb_rule").value=="")
            document.getElementById("comb_rule").value=0;
        if (document.getElementById("weight_mode").value=="")
            document.getElementById("weight_mode").value=0;
    }
    if (document.getElementById("NBpot_type").value>0)
    {
        if (document.getElementById("lead_pot_ind").value=="")
            document.getElementById("lead_pot_ind").value=0;
    }
    if (document.getElementById("NBpot_type").value==10)
    {
        if (document.getElementById("ntab_pot").value=="")
            document.getElementById("ntab_pot").value=0;
    }
}

function UpdateNtypes()
{
    ntypes=parseInt(document.getElementById("ntypes").value);
    npartials=ntypes*(ntypes+1)/2;
    if (document.getElementById("NBpot_type")==10)
        document.getElementById("ntab_pot").max=npartials;
    if (document.getElementById("NBpot_type").value==1)
    {
        if (document.getElementById("weight_mode").value==1)
        {
            nNB_tot=2*npartials;
            npotser_tot=nNB_tot+nbonded_tot;
            document.getElementById("leadpot_tot_space").innerHTML="";
            blocks.push(new smallBlock("leadpot_tot_space", [
                {id:"leadpot_tot", type: "text", default: npotser_tot, width_inp: "width:140px", align: "left", hidden:true},
            ],-1));
        }
        
        CheckLeadPotIndTot();
    }
    
}
function save() 
{
    sigma_pot_index=0;
    prev_type="NONE";
    function download(filename, text) {
        var pom = document.createElement('a');
        pom.setAttribute('href', 'data:text/plain;charset=utf-8,' + encodeURIComponent(text));
        pom.setAttribute('download', filename);
    
        if (document.createEvent) {
            var event = document.createEvent('MouseEvents');
            event.initEvent('click', true, true);
            pom.dispatchEvent(event);
        }
        else {
            pom.click();
        }
    }

    var my_text;
    var write_flag=1;
    
    my_text= "#002"+blocks.reduce((acm, block)=> 
    {
        var mydata=block.getData();
        if (mydata=="abort")
        {
          
            write_flag=0;
            return mydata;
        }
        else
            return acm + mydata;
    }, "");
    if (write_flag)
    {
        download("RMC.dat", my_text, "");
    }
   // download("RMC.dat", blocks.reduce((acm, block)=> {
    //    return acm + block.getData();
    //}, ""));
}